@@ -4,15 +4,15 @@ package Devel::Decouple;
 use strict;
 use warnings;
 use Carp;
-use version; our $VERSION = qv(0.0.2);
+use version; our $VERSION = qv(0.0.3);
 
 use base 'Exporter';
-our @EXPORT = (qw{ from function functions as default_sub preserved });
+our @EXPORT = qw{ from function functions as default_sub preserved };
 
 use Class::Inspector;
 use PPI::Document;
 use PPI::Find;
-use Monkey::Patch qw{ patch_package };
+use Monkey::Patch   qw{ patch_package };
 use List::MoreUtils qw{ uniq };
 
 ### PUBLIC METHODS: ########################
@@ -88,9 +88,9 @@ sub revert{
 sub report{
     my $self = shift;
     
-    return $self->module
+    return $self->document
         ? $self->_build_report
-        : die qq{ 'report' called on uninitialized object };
+        : croak qq{ 'report' called on uninitialized object };
 }
 
 ### EXPORTS FOR SYNTACTIC SUGAR: ###########
@@ -144,9 +144,9 @@ sub _build_report {
     
     for my $module ( $self->modules ){
         $report .= " "x($indent)."$module\n";
-        map { $report .= " "x(2*$indent)."$_"." "x($spacing-length($_))."called ".
-              $self->{_CALLED_IMPORT_STATS_}{$module}{$_}{ _NUMBER_OF_CALLS_ }." times at line(s): ". 
-              (join ', ', @{$self->{_CALLED_IMPORT_STATS_}{$module}{$_}{_LINE_NUMBERS_}}).".\n" }
+        map { $report .= " "x(2*$indent)."$_"." "x($spacing-length($_))."calls: ".
+              $self->{_CALLED_IMPORT_STATS_}{$module}{$_}{ _NUMBER_OF_CALLS_ }."\tlines: ". 
+              (join ',', @{$self->{_CALLED_IMPORT_STATS_}{$module}{$_}{_LINE_NUMBERS_}}).".\n" }
             sort keys %{$self->{_CALLED_IMPORT_STATS_}{$module}};
     }
     
@@ -157,11 +157,10 @@ sub _build_imports {
     my $self = shift;
     
     my ($CallFinder,$Document) = $self->_create_call_finder;
+    my @found = $CallFinder->in( $Document );
     
     for my $module ( $self->_get_modules ){
         no strict 'refs';
-        my @found = $CallFinder->in( $Document );
-        
         for my $function ( @{$module.'::EXPORT'}, @{$module.'::EXPORT_OK'} ){
             for my $token ( @found ){
                 if ( $token eq $function ){
@@ -237,7 +236,7 @@ Devel::Decouple - Decouple code from imported functions
 
 This module is intended to facilitate the testing and refactoring of legacy Perl code.
 
-To generate a simple report about a module's or script's use of imported functions you can simply use the Devel::Decouple subclass Devel::Decouple::DB via the debugger.
+To generate a simple report about a module's or script's use of imported functions you can simply use the C<Devel::Decouple> subclass C<Devel::Decouple::DB> via the debugger.
     
     perl -d:Decouple::DB myscript.pl
     
@@ -278,7 +277,7 @@ This module also provides for a high degree of customization of how, or whether,
             default_sub, as { warn "calling '",  (caller(0))[3],
                                    "' from ",    (caller(1))[3],
                                    " at line ",  (caller(0))[2];
-                              return shift->(@_) });
+                              shift->(@_) });
     
     
 =head1 DESCRIPTION
@@ -293,7 +292,7 @@ When faced with maintaining and extending such code this brings to light several
 
 Further, because legacy Perl code uses predominantly functional interfaces, rather than object orientation, it often pollutes the consumers name-space with imported functions (and other symbols) that can be difficult to identify. Our only recourse in the past has generally been to eyeball the code, perhaps several thousand lines of it, and make careful notes.
 
-C<Devel::Decouple> is designed to do static analysis on the parts of the code that you intend to create Characterization tests (L<http://en.wikipedia.org/wiki/Characterization_Test>) for to facilitate refactoring. It can programmatically identify the imported functions that have I<actually been called> for the given name-space. It can also automatically install default stub functions into the symbol table to replace these functions, or allow the specification of individual and specialized behavior (e.g. returning mocked data from a tabular data-file or here-doc in a standard Test::More test script).
+C<Devel::Decouple> is designed to do static analysis on the parts of the code that you intend to create Characterization tests (L<http://en.wikipedia.org/wiki/Characterization_Test>) for to facilitate refactoring. It can programmatically identify the imported functions that have I<actually been called> for the given name-space. It can also automatically install default stub functions into the symbol table to replace these functions, or allow the specification of individual and specialized behavior (e.g. returning mocked data from a tabular data-file or here-doc in a standard L<Test::More> test script).
 
 
 =head1 INTERFACE 
@@ -428,7 +427,7 @@ Behavior to install in the symbol table. The C<as> sub-clause must follow C<func
 
 =over
 
-Specify default behavior for any called function that has no other explicitly defined custom behavior and which is not C<preserved>. Use an C<as> clause to define the behavior itself. If not specified the default C<default_sub> is a no-op that always simply returns C<undef>.
+Specify the default override behavior for any called (imported) function that has no other explicitly defined custom behavior and which is not C<preserved>. Use an C<as> clause to define the behavior itself. If not specified the default C<default_sub> is a no-op that always simply returns C<undef>.
 
 It is of course possible for the C<default_sub> to specify that the previously defined behavior should be preserved:
 
@@ -548,7 +547,7 @@ In contrast, calling C<decouple> on an I<already defined> C<Devel::Decouple> obj
     
     ### And so on...
     
-Caution should be exercised here as the C<Devel::Decouple> object instances are actually collections of stacks maintained for each function. It can become confusing to keep track of what behavior was specified in which objects and how those objects relate to the ordering of the underlying stacks. Please see L<Testing Kata> for some ideas about how to deal with this issue.
+Caution should be exercised here as the C<Devel::Decouple> object instances are actually collections of stacks maintained for each function. It can become confusing to keep track of what behavior was specified in which objects and how those objects relate to the ordering of the underlying stacks. Please see L<Devel::Decouple Testing Kata> for some ideas about how to deal with this issue.
 
 =back
 
@@ -565,15 +564,15 @@ For any function definition you provide you have access to the immediately previ
     my $Decoupler = Devel::Decouple->new;
     $Decoupler->decouple( 'My::Module',
                         default_sub, as { my $orig = shift;
-                                          warn (caller(0))[3],
-                                               "called with args: ",
+                                          warn ("'", caller(0))[3],
+                                               "' called with args: ",
                                                join '=|=', @_;
                                           $orig->(@_)},                 # redispatch!
                         );
 
 If you wish, you can redispatch to any arbitrary depth down the stack of function definitions in this way, continually passing the original arguments along until ultimately terminating at the original source function definition.
 
-Combining the use of the stack and this re-dispatch mechanism is a powerful way to implement stack traces, data serialization, and other exploratory testing for I<all> the functions in a complex or convoluted name-space. C<Devel::Decouple> isn't just for redefining the imported functions, although these can be automated to a greater extent by the use of the C<default_sub> clause. C<Devel::Decouple> can redine natively defined functions when listed explicitly in a C<function> or C<functions> clause.
+Combining the use of the stack and this re-dispatch mechanism is a powerful way to implement stack traces, data serialization, and other exploratory testing for I<all> the functions in a complex or convoluted name-space. C<Devel::Decouple> isn't just for redefining the imported functions, although these can be automated to a greater extent by the use of the C<default_sub> clause. C<Devel::Decouple> can redefine native functions when listed explicitly in a C<function> or C<functions> clause.
 
 Using such a technique can help you to understand the behavior of legacy Perl code so that you can clear the seemingly insurmountable hurdle of writing the initial tests. By automating much of the exploratory analysis of dense code it can also aid you in gradually adding increasingly granular test cases as you begin to better understand the behavior of your code. Once you understand the behavior of your code well and have a handle on complex dependencies then safely refactoring toward a more modern and maintainable idiom is possible.
 
@@ -601,12 +600,16 @@ Devel::Decouple requires no configuration files or environment variables.
 
 C<Devel::Decouple> does not currently identify imported symbols other than subroutines.
 
-Please report any bugs or feature requests to L<dev@namimedia.com>.
+Please report any bugs or feature requests to <F<dev@namimedia.com>>.
 
 
+=head1 AUTHOR
+
+Montgomery Conner <F<mconner@cpan.org>>
+
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2012, NamiMedia C<dev@namimedia.com>. All rights reserved.
+Copyright (c) 2012, NamiMedia <F<dev@namimedia.com>>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
